@@ -14,16 +14,13 @@ where
 /// Returns the value of PKG_DBDIR if exists or a default if not.
 pub fn pkgdb_dir() -> Option<PathBuf> {
     if let Ok(lines) = read_lines("/etc/mk.conf") {
-        for line in lines.flatten() {
-            if line.starts_with("PKG_DBDIR") {
-                let pkg_db = PathBuf::from(line.split('=').nth(1).unwrap().trim().to_string());
-                if pkg_db.is_dir() {
-                    return Some(pkg_db);
-                }
-            }
+        let line = lines.flatten().find(|l| l.starts_with("PKG_DBDIR"));
 
-            continue;
-        }
+        if let Some(pkg_dbdir) = line {
+            if let Some(value) = pkg_dbdir.split('=').nth(1) {
+                return Some(PathBuf::from(value.trim()));
+            }
+        };
     }
 
     Some(PathBuf::from("/usr/pkg/pkgdb"))
@@ -32,16 +29,13 @@ pub fn pkgdb_dir() -> Option<PathBuf> {
 /// Returns the value of LOCALBASE if exists or a default if not.
 pub fn localbase_dir() -> Option<PathBuf> {
     if let Ok(lines) = read_lines("/etc/mk.conf") {
-        for line in lines.flatten() {
-            if line.starts_with("LOCALBASE") {
-                let localbase = PathBuf::from(line.split('=').nth(1).unwrap().trim().to_string());
-                if localbase.is_dir() {
-                    return Some(localbase);
-                }
-            }
+        let line = lines.flatten().find(|l| l.starts_with("LOCALBASE"));
 
-            continue;
-        }
+        if let Some(pkg_dbdir) = line {
+            if let Some(value) = pkg_dbdir.split('=').nth(1) {
+                return Some(PathBuf::from(value.trim()));
+            }
+        };
     }
 
     Some(PathBuf::from("/usr/pkg"))
