@@ -2,7 +2,6 @@ use crate::dirs;
 use crate::extra;
 use crate::shared;
 use crate::traits::*;
-use byte_unit::AdjustedByte;
 use itertools::Itertools;
 use nix::unistd;
 use regex::Regex;
@@ -318,7 +317,7 @@ impl GeneralReadout for NetBSDGeneralReadout {
         Err(ReadoutError::MetricNotAvailable)
     }
 
-    fn disk_space(&self) -> Result<(AdjustedByte, AdjustedByte), ReadoutError> {
+    fn disk_space(&self) -> Result<(u128, u128), ReadoutError> {
         let mut s: std::mem::MaybeUninit<libc::statvfs> = std::mem::MaybeUninit::uninit();
         let path = CString::new("/").expect("Could not create C string for disk usage path.");
 
@@ -328,10 +327,8 @@ impl GeneralReadout for NetBSDGeneralReadout {
             let disk_size = stats.f_blocks * stats.f_bsize as u64;
             let free = stats.f_bavail * stats.f_bsize as u64;
 
-            let used_byte =
-                byte_unit::Byte::from_bytes((disk_size - free) as u128).get_appropriate_unit(true);
-            let disk_size_byte = byte_unit::Byte::from_bytes(disk_size as u128)
-                .get_adjusted_unit(used_byte.get_unit());
+            let used_byte = (disk_size - free) as u128;
+            let disk_size_byte = disk_size as u128;
 
             return Ok((used_byte, disk_size_byte));
         }
